oerplib.service.osv
===================

oerplib.service.osv.Model
'''''''''''''''''''''''''

.. autoclass:: oerplib.service.osv.Model
    :members:

oerplib.service.osv.BrowseRecord
''''''''''''''''''''''''''''''''

.. autoclass:: oerplib.service.osv.BrowseRecord
    :members:

